@@ -1,11 +1,11 @@
 text = """
-    Heat the oil in a large pan and add the Onion, celery and carrots. 
-    Then, cook over a medium–low heat for 10 minutes, or until softened. 
+    Heat the oil in a large pan and add the Onion, celery and carrots.
+    Then, cook over a medium–low heat for 10 minutes, or until softened.
     Add the courgette, garlic, red peppers and oregano and cook for 2–3 minutes.
     Later, add some oranges, chickens. """
-    
+
 data = {
     "fruit": ["apple", "pear", "orange"],
     "vegetable": ["broccoli", "spinach", "tomato"],
-    "meat": ["chicken", "beef", "pork", "fish", "lamb"]
+    "meat": ["chicken", "beef", "pork", "fish", "lamb"],
 }
